.. -*- rst -*-

========
picamera
========

This package provides a pure Python interface to the `Raspberry Pi`_ `camera`_
module for Python 2.7 (or above) or Python 3.2 (or above).

The code is licensed under the `BSD license`_. Packages can be downloaded from
the project `homepage`_ on PyPI. The `source code`_ can be obtained from
GitHub, which also hosts the `bug tracker`_. The `documentation`_ (which
includes installation, quick-start examples, and lots of code recipes) can be
read on ReadTheDocs.


.. _Raspberry Pi: http://www.raspberrypi.org/
.. _camera: http://www.raspberrypi.org/camera
.. _homepage: http://pypi.python.org/pypi/picamera/
.. _documentation: http://picamera.readthedocs.org/
.. _source code: https://github.com/waveform80/picamera
.. _bug tracker: https://github.com/waveform80/picamera/issues
.. _Python: http://python.org/
.. _BSD license: http://opensource.org/licenses/BSD-3-Clause
.. _Pull requests: https://github.com/waveform80/picamera.git
